##  Fact Sheet Layout
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe7f47c9b770d4260ae40aaedbb0f4e90_LowRes.gif)
Fact Sheet Layout
  * Header: This section contains the principal information, such as the fact sheet name, type, data completion percentage, quality seal status, and option to subscribe to the fact sheet. It also contains menu options for editing, printing, deleting, or cloning the fact sheet.
  * Body: It contains all relevant information about the fact sheet in detail, such as lifecycle, criticality, dependencies, etc. The information is structured in sections for easy access, addition, or updating.
  * Tabs: Different tabs provide options to view and subscribe to the current fact sheet, add comments or resources, view metrics and surveys, and see the change history of the current fact sheet.
  * Right Side Panel: The panel shows the active integrations for the fact sheet, along with to-dos, recently viewed fact sheets, and related diagrams.
